@@ -7,14 +7,14 @@
 #define __M4RI_HAVE_SSE2		1
 #define __M4RI_HAVE_OPENMP		1
 #define __M4RI_CPU_L1_CACHE		32768
-#define __M4RI_CPU_L2_CACHE		524288
-#define __M4RI_CPU_L3_CACHE		16777216
+#define __M4RI_CPU_L2_CACHE		1048576
+#define __M4RI_CPU_L3_CACHE		33554432
 #define __M4RI_DEBUG_DUMP		(0 || 0)
 #define __M4RI_DEBUG_MZD		0
 #define __M4RI_HAVE_LIBPNG              1
 
 #define __M4RI_CC                       "gcc"
-#define __M4RI_CFLAGS                   " -mmmx -msse -msse2 -msse3 -fopenmp -march=x86-64 -mtune=generic -O2 -pipe -fno-plt"
+#define __M4RI_CFLAGS                   " -mmmx -msse -msse2 -msse3 -fopenmp -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/m4ri/src=/usr/src/debug/m4ri -flto=auto"
 #define __M4RI_SIMD_CFLAGS              " -mmmx -msse -msse2 -msse3"
 #define __M4RI_OPENMP_CFLAGS            "-fopenmp"
 
